==> web-6.0.0.tgz: package/lib/treeTable/TrItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { activeStatus } from './formatterTreeData';
class Item extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clickFn = (e) => {
            const index = e.currentTarget.dataset.index;
            const { changeState } = this.props;
            changeState(index, 'expand');
        };
        this.checkFn = (e) => {
            e.stopPropagation();
            const dom = e.currentTarget;
            const index = dom.parentElement.dataset.index;
            const { changeState, isPar } = this.props;
            changeState(index, isPar ? 'checkPar' : 'active');
        };
    }
    getCheck() {
        const { fixObj: { multiply } } = this.props;
        if (multiply) {
            const { node } = this.props;
            const active = node.get('active') === activeStatus.hasSelect ?
                'checkbox-has-selected' :
                node.get('active') === activeStatus.noSelect ? 'checkbox-blank' : 'checkbox-marked';
            return (React.createElement(SvgIcon, { className: active }));
        }
        else {
            return undefined;
        }
    }
    getIcon() {
        const { node, isPar, fixObj: { itemIcon = 'file' } } = this.props;
        if (isPar) {
            const expand = node.get('expand');
            return (React.createElement(React.Fragment, null,
                React.createElement(SvgIcon, { className: expand ? "minus" : "plus" }),
                React.createElement(SvgIcon, { className: expand ? "folder-open" : "folder" })));
        }
        else {
            return React.createElement(SvgIcon, { className: itemIcon });
        }
    }
    getFirstText(text) {
        const { lev, isPar, index, fixObj: { multiply } } = this.props;
        const fn = isPar ? this.clickFn : undefined;
        const className = isPar ? "tree-par" : undefined;
        const check = multiply ? this.checkFn : undefined;
        const checkName = multiply ? 'tree-check' : undefined;
        return (React.createElement("div", { onClick: fn, className: className, "data-index": index },
            React.createElement("span", { onClick: check, className: checkName },
                React.createElement("span", { style: { paddingRight: lev * 14, } }),
                this.getCheck(),
                this.getIcon(),
                text)));
    }
    getOrder() {
        const { order } = this.props;
        order.order++;
        return order.order;
    }
    render() {
        const { cols, node, fixObj: { tabField, noOrder }, isMainView } = this.props;
        const tds = cols.map((td, index) => {
            const { field, formatter, align } = td;
            const text = formatter ? formatter(node, index, tabField) : node.get(field);
            let str;
            let alignName = align ? `td-${align}` : '';
            if (isMainView) {
                if (noOrder) {
                    str = index === 0 ? this.getFirstText(text) : text;
                }
                else {
                    str = index === 0 ? this.getOrder() : index === 1 ? this.getFirstText(text) : text;
                    alignName = index === 1 ? "" : alignName;
                }
            }
            else {
                str = text;
            }
            return (React.createElement("td", { key: field, className: `td-border ${alignName}` }, str));
        });
        return (React.createElement("tr", null, tds));
    }
}
export default Item;

==> web-9.0.0.tgz: package/lib/treeTable/TrItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { activeStatus } from './formatterTreeData';
class Item extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.slideIconEvent = (e) => {
            e.stopPropagation();
            const index = e.currentTarget.parentElement.parentElement.dataset.index;
            this.props.changeState(index, "expand");
        };
        this.clickFn = (e) => {
            const index = e.currentTarget.dataset.index;
            const { changeState } = this.props;
            changeState(index, 'expand');
        };
        this.checkFn = (e) => {
            e.stopPropagation();
            const dom = e.currentTarget;
            const index = dom.parentElement.dataset.index;
            const { changeState, isPar } = this.props;
            changeState(index, isPar ? 'checkPar' : 'active');
        };
    }
    getCheck() {
        const { fixObj: { multiply } } = this.props;
        if (multiply) {
            const { node } = this.props;
            const active = node.get('active') === activeStatus.hasSelect ?
                'checkbox-has-selected' :
                node.get('active') === activeStatus.noSelect ? 'checkbox-blank' : 'checkbox-marked';
            return (React.createElement(SvgIcon, { className: active }));
        }
        else {
            return undefined;
        }
    }
    getIcon() {
        const { node, isPar, fixObj: { itemIcon = 'file', multiply } } = this.props;
        if (isPar) {
            const expand = node.get('expand');
            return (React.createElement(React.Fragment, null,
                React.createElement("span", { onClick: multiply ? this.slideIconEvent : undefined },
                    React.createElement(SvgIcon, { className: expand ? "minus" : "plus" })),
                React.createElement(SvgIcon, { className: expand ? "folder-open" : "folder" })));
        }
        else {
            return React.createElement(SvgIcon, { className: itemIcon });
        }
    }
    getFirstText(text) {
        const { lev, isPar, index, fixObj: { multiply } } = this.props;
        const fn = isPar ? this.clickFn : undefined;
        const className = isPar ? "tree-par" : undefined;
        const check = multiply ? this.checkFn : undefined;
        const checkName = multiply ? 'tree-check' : undefined;
        return (React.createElement("div", { onClick: fn, className: className, "data-index": index },
            React.createElement("span", { onClick: check, className: checkName },
                React.createElement("span", { style: { paddingRight: lev * 14, } }),
                this.getCheck(),
                this.getIcon(),
                text)));
    }
    getOrder() {
        const { order } = this.props;
        order.order++;
        return order.order;
    }
    render() {
        const { cols, node, fixObj: { tabField, noOrder }, isMainView } = this.props;
        const tds = cols.map((td, index) => {
            const { field, formatter, align } = td;
            const text = formatter ? formatter(node, index, tabField) : node.get(field);
            let str;
            let alignName = align ? `td-${align}` : '';
            if (isMainView) {
                if (noOrder) {
                    str = index === 0 ? this.getFirstText(text) : text;
                }
                else {
                    str = index === 0 ? this.getOrder() : index === 1 ? this.getFirstText(text) : text;
                    alignName = index === 1 ? "" : alignName;
                }
            }
            else {
                str = text;
            }
            return (React.createElement("td", { key: field, className: `td-border ${alignName}` }, str));
        });
        return (React.createElement("tr", null, tds));
    }
}
export default Item;
